@@ -231,6 +231,21 @@ static int
 irt_rpf_mdim_drm_numParam(const double *spec)
 { return 3 + spec[RPF_ISpecDims]; }
 
+static void
+irt_rpf_mdim_drm_paramBound(const double *spec, const int param,
+			    double *upper, double *lower)
+{
+	int numDims = spec[RPF_ISpecDims];
+	*upper = nan("unset");
+	*lower = nan("unset");
+	if (param >= 0 && param < numDims) {
+		*lower = 1e-6;
+	} else if (param == numDims+1 || param == numDims+2) {
+		*lower = 1e-6;
+		*upper = 1 - 1e-6;
+	}
+}
+
 static void
 irt_rpf_mdim_drm_prob(const double *spec,
 		      const double *restrict param, const double *restrict th,
@@ -472,6 +487,18 @@ static int
 irt_rpf_mdim_grm_numParam(const double *spec)
 { return spec[RPF_ISpecOutcomes] + spec[RPF_ISpecDims] - 1; }
 
+static void
+irt_rpf_mdim_grm_paramBound(const double *spec, const int param,
+			    double *upper, double *lower)
+{
+	int numDims = spec[RPF_ISpecDims];
+	*upper = nan("unset");
+	*lower = nan("unset");
+	if (param >= 0 && param < numDims) {
+		*lower = 1e-6;
+	}
+}
+
 static void
 irt_rpf_mdim_grm_prob(const double *spec,
 		      const double *restrict param, const double *restrict th,
@@ -689,6 +716,18 @@ irt_rpf_nominal_numParam(const double *spec)
 { return spec[RPF_ISpecDims] + 2 * (spec[RPF_ISpecOutcomes]-1); }
 
 
+static void
+irt_rpf_nominal_paramBound(const double *spec, const int param,
+			   double *upper, double *lower)
+{
+	int numDims = spec[RPF_ISpecDims];
+	*upper = nan("unset");
+	*lower = nan("unset");
+	if (param >= 0 && param < numDims) {
+		*lower = 1e-6;
+	}
+}
+
 static void
 _nominal_rawprob(const double *spec,
 		 const double *restrict param, const double *restrict th,
@@ -1163,6 +1202,7 @@ const struct rpf librpf_model[] = {
   { "drm1-",
     irt_rpf_1dim_drm_numSpec,
     irt_rpf_1dim_drm_numParam,
+    irt_rpf_mdim_drm_paramBound,
     irt_rpf_1dim_drm_prob,
     irt_rpf_logprob_adapter,
     irt_rpf_1dim_drm_deriv1,
@@ -1173,6 +1213,7 @@ const struct rpf librpf_model[] = {
   { "drm1",
     irt_rpf_1dim_drm_numSpec,
     irt_rpf_1dim_drm_numParam,
+    irt_rpf_mdim_drm_paramBound,
     irt_rpf_1dim_drm_prob,
     irt_rpf_logprob_adapter,
     notimplemented,
@@ -1183,6 +1224,7 @@ const struct rpf librpf_model[] = {
   { "drm1+",
     irt_rpf_mdim_drm_numSpec,
     irt_rpf_mdim_drm_numParam,
+    irt_rpf_mdim_drm_paramBound,
     irt_rpf_mdim_drm_prob,
     irt_rpf_logprob_adapter,
     irt_rpf_mdim_drm_deriv1,
@@ -1193,6 +1235,7 @@ const struct rpf librpf_model[] = {
   { "drm",
     irt_rpf_mdim_drm_numSpec,
     irt_rpf_mdim_drm_numParam,
+    irt_rpf_mdim_drm_paramBound,
     irt_rpf_mdim_drm_prob,
     irt_rpf_logprob_adapter,
     irt_rpf_mdim_drm_deriv1,
@@ -1203,6 +1246,7 @@ const struct rpf librpf_model[] = {
   { "grm1",
     irt_rpf_mdim_grm_numSpec,
     irt_rpf_mdim_grm_numParam,
+    irt_rpf_mdim_grm_paramBound,
     irt_rpf_1dim_grm_prob,
     irt_rpf_logprob_adapter,
     noop, // TODO fill in pre/post transformation
@@ -1213,6 +1257,7 @@ const struct rpf librpf_model[] = {
   { "grm",
     irt_rpf_mdim_grm_numSpec,
     irt_rpf_mdim_grm_numParam,
+    irt_rpf_mdim_grm_paramBound,
     irt_rpf_mdim_grm_prob,
     irt_rpf_logprob_adapter,
     irt_rpf_mdim_grm_deriv1,
@@ -1223,6 +1268,7 @@ const struct rpf librpf_model[] = {
   { "nominal",
     irt_rpf_nominal_numSpec,
     irt_rpf_nominal_numParam,
+    irt_rpf_nominal_paramBound,
     irt_rpf_nominal_prob,
     irt_rpf_nominal_logprob,
     irt_rpf_nominal_deriv1,
